@@ -20,7 +20,6 @@
 
 #include "gdk-pixbuf-private.h"
 #include "gdk-pixdata.h"
-#include "gdk-pixbuf-alias.h"
 #include <string.h>
 
 #define APPEND g_string_append_printf
@@ -898,6 +897,3 @@ gdk_pixbuf_new_from_inline (gint          data_length,
 
   return gdk_pixbuf_from_pixdata (&pixdata, copy_pixels, error);
 }
-
-#define __GDK_PIXDATA_C__
-#include "gdk-pixbuf-aliasdef.c"
